@@ -5,7 +5,7 @@ from httpcore._async.connection import AsyncHTTPConnection  # noqa
 from httpcore._utils import url_to_origin  # noqa
 from httpx._config import SSLConfig  # noqa
 
-from .core_socks import ProxyType, parse_proxy_url
+from python_socks import ProxyType, parse_proxy_url
 
 
 class AsyncProxyTransport(AsyncConnectionPool):
@@ -32,36 +32,44 @@ class AsyncProxyTransport(AsyncConnectionPool):
 
         super().__init__(http2=http2, ssl_context=ssl_context, **kwargs)
 
-    async def request(self, method, url, headers=None, stream=None,
-                      timeout=None):
+    async def arequest(self, method, url, headers=None, stream=None,
+                       ext=None):
 
         origin = url_to_origin(url)
         connection = await self._get_connection_from_pool(origin)
 
+        ext = {} if ext is None else ext
+        timeout = ext.get('timeout', {})
+        connect_timeout = timeout.get('connect')
+
         if connection is None:
-            socket = await self._connect_to_proxy(origin=origin,
-                                                  timeout=timeout)
+            socket = await self._connect_to_proxy(
+                origin=origin,
+                connect_timeout=connect_timeout
+            )
             connection = AsyncHTTPConnection(
                 origin=origin,
                 http2=self._http2,
                 ssl_context=self._ssl_context,
                 socket=socket
             )
-            await self._add_to_pool(connection)
+            await self._add_to_pool(connection=connection, timeout=timeout)
 
-        response = await connection.request(method, url, headers, stream,
-                                            timeout)
+        response = await connection.arequest(
+            method=method,
+            url=url,
+            headers=headers,
+            stream=stream,
+            ext=ext
+        )
         return response
 
-    async def _connect_to_proxy(self, origin, timeout):
+    async def _connect_to_proxy(self, origin, connect_timeout):
         scheme, hostname, port = origin
 
         ssl_context = self._ssl_context if scheme == b'https' else None
         host = hostname.decode('ascii')  # ?
 
-        timeout = {} if timeout is None else timeout
-        connect_timeout = timeout.get('connect')
-
         return await self._open_stream(
             host=host,
             port=port,
@@ -76,7 +84,7 @@ class AsyncProxyTransport(AsyncConnectionPool):
 
             import asyncio
             from httpcore._backends.asyncio import SocketStream  # noqa
-            from .core_socks.async_.asyncio import Proxy
+            from python_socks.async_.asyncio import Proxy
 
             if self._loop is None:
                 self._loop = asyncio.get_event_loop()
@@ -92,9 +100,8 @@ class AsyncProxyTransport(AsyncConnectionPool):
             )
 
             sock = await proxy.connect(host, port, timeout=connect_timeout)
-            # noinspection PyTypeChecker
+
             stream_reader, stream_writer = await asyncio.open_connection(
-                loop=self._loop,
                 host=None,
                 port=None,
                 sock=sock,
@@ -109,7 +116,7 @@ class AsyncProxyTransport(AsyncConnectionPool):
 
             import trio
             from httpcore._backends.trio import SocketStream  # noqa
-            from .core_socks.async_.trio import Proxy
+            from python_socks.async_.trio import Proxy
 
             proxy = Proxy.create(
                 proxy_type=self._proxy_type,
